@@ -15,7 +15,7 @@ use List::Compare;
 use List::MoreUtils qw(none uniq firstval);
 use Scalar::Util qw(weaken);
 
-our $VERSION = '1.24';
+our $VERSION = '1.25';
 
 my %translation = (
 	2  => 'Polizeiliche Ermittlung',
@@ -71,6 +71,7 @@ my %translation = (
 	63 => 'Technische Untersuchung am Zug',
 	64 => 'Weichenstörung',
 	65 => 'Erdrutsch',
+	66 => 'Hochwasser',
 	70 => 'Kein WLAN',
 	71 => 'WLAN in einzelnen Wagen nicht verfügbar',
 	73 => 'Mehrzweckabteil vorne',
@@ -811,7 +812,7 @@ arrival/departure received by Travel::Status::DE::IRIS
 
 =head1 VERSION
 
-version 1.24
+version 1.25
 
 =head1 DESCRIPTION
 
@@ -1306,6 +1307,10 @@ Source: correlation between IRIS and DB RIS (bahn.de).
 
 Source: correlation between IRIS and DB RIS (bahn.de).
 
+=item d 66 : "Hochwasser"
+
+Source: correlation between IRIS and DB RIS (bahn.de).
+
 =item q 70 : "Kein WLAN"
 
 Source: correlation between IRIS and DB RIS (bahn.de).
